@@ -172,6 +172,8 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         X = [0] * N
         for i in range(N) :
             order = dims[i] - 1
+            if not order > 0 :
+                continue
             Xi = [0] * order
             Xi0 = args[i]
             Xi[0] = Xi0
@@ -214,3 +216,11 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         as for :meth:`diff`.
         """
         return MVPolyCube(mvpoly.util.cube.int(self.coef, args))
+
+    def maxmodnb(self, *args) :
+        """
+        Maximum modulus of the polynomial on the unit ball, this
+        method is only available if the :mod:`maxmodnb` package
+        is installed (and that is in an early stage of development).
+        """
+        return mvpoly.util.cube.maxmodnb(self.coef, *args)
