@@ -204,6 +204,7 @@ def horner(p, dtype=float, *args) :
         x.shape = (dx[0], -1)
         y = horner_recurse(p, dp, nvp, x)
         y.shape = dx[1:]
+
     else :
         x = np.array(args)
         y = horner_recurse(p, dp, nvp, x)
@@ -213,3 +214,10 @@ def horner(p, dtype=float, *args) :
     else :
         return y.flat[0]
 
+def maxmodnb(p, eps = 1e-10) :
+    """
+    Return the maximum modulus of the polynomial whose
+    coefficients are given by the array *p*. Requires the
+    :mod:`maxmodnb` package (not yet released).
+    """
+    return __import__("maxmodnb").maxmodnb(p, eps)
