@@ -468,12 +468,15 @@ class TestMVPolyCubeCompose(unittest.TestCase) :
         x, y = MVPolyCube.monomials(2, dtype=int)
         p = x + y
         self.assertTrue(isinstance(p(1, y), MVPolyCube), "bad call/compose")
-
-    def test_call_compose(self) :
-        x, y = MVPolyCube.monomials(2, dtype=int)
-        p = x + y
         self.assertTrue(isinstance(p(1, 2), int), "bad call/eval")
-        
+
+    def test_compose_1of2(self) :
+        x, y = MVPolyCube.monomials(2, dtype=int)        
+        p = x + 1
+        q = p.compose(y, x)
+        self.assertTrue(q(1, 0) == 1, "bad compose")
+
+
 class TestMVPolyCubeHomdeg(unittest.TestCase) :
 
     def test_homdeg_1d(self) :
@@ -483,7 +486,7 @@ class TestMVPolyCubeHomdeg(unittest.TestCase) :
         expected = 5
         self.assertTrue(expected == obtained, 
                         "bad homdeg %s" % \
-                            repr(expected))
+                            repr(obtained))
 
     def test_homdeg_2d(self) :
         x, y = MVPolyCube.monomials(2, dtype=int)
@@ -492,7 +495,30 @@ class TestMVPolyCubeHomdeg(unittest.TestCase) :
         expected = 7
         self.assertTrue(expected == obtained, 
                         "bad homdeg %s" % \
-                            repr(expected))
+                            repr(obtained))
+
+# this will not be added for a while, it is here just to
+# check that mvpoly integration works for the author
+
+def have_maxmodnb() :
+    try:
+        import maxmodnb
+    except ImportError:
+        return False
+    return True
+
+@unittest.skipUnless(have_maxmodnb(), "maxmodnb not installed")
+class TestMVPolyCubeMaxmodnb(unittest.TestCase) :
+
+    def test_maxmodnb_simple(self) :
+        eps = 1e-10
+        x, y = MVPolyCube.monomials(2, dtype=complex)
+        p = x**2 + 1
+        obtained = p.maxmodnb(eps)[0]
+        expected = 2.0
+        self.assertTrue(abs(expected - obtained) < eps*expected, 
+                        "bad maxmodnb %s" % repr(obtained))
+        
 
 if __name__ == '__main__':
     unittest.main()
